@@ -1,5 +1,4 @@
-from datetime import date
-from thetadata import ThetaClient, OptionRight, StreamMsg, StreamMsgType
+from thetadata import ThetaClient, StreamMsg, StreamMsgType
 
 
 def streaming():
